/*
	Copyright Cornell University 1986.  All rights are reserved.
*/

/*
	This include file defines the internal result codes used in translating
	user events into actions for the terminal emulator.  Each result code
	is two bytes long, the first byte is the class type, and the second
	is an entry id for that type. 
*/

/* token classes */

#define	RSLT_ASCI	0x20	/* ' ' ascii character	*/
#define RSLT_LCAC	0x41	/* 'A' IBM local action key	*/
#define RSLT_EMC	0x43	/* 'C' emulator control */
#define RSLT_SCOPY	0x63	/* 'c' special copy routines */
#define RSLT_DELAY	0x44	/* 'D' delay */
#define RSLT_EDIT	0x45	/* 'E' EDIT action */
#define RSLT_FILE	0x46	/* 'F' FILE action */
#define RSLT_LOOP	0x4C	/* 'L' LOOP with count argument */
#define RSLT_MVCR	0x4D	/* 'M' IBM cursor movement key */
#define RSLT_PFKY	0x50	/* 'P' IBM program function key */
#define RSLT_SEL1	0x53	/* 'S' selection Y start */
#define RSLT_SEL2	0x54	/* 'T' selection X start */
#define RSLT_SEL3	0x55	/* 'U' selection Y end */
#define RSLT_SEL4	0x56	/* 'V' selection X end */
#define RSLT_WIND	0x57	/* 'W' window selection action */
#define RSLT_XCURS	0x58	/* 'X' cursor movement to x loc	*/
#define RSLT_YCURS	0x59	/* 'Y' cursor movement to y loc	*/
#define RSLT_MATCH	0x5A	/* 'Z' delay for input match */

#define RSLT_TELNET	0x74	/* 't' Telnet commands */


/* RSLT_ASCI entries */

/* the entry for the rslt_asci type is the desired x location */

/* 'A' RSLT_LCAC entries */

#define BACKSP_BLANK	0x20	/* space */
#define BACKSP_DEL	0x42		/* B */
#define DEL_CHAR	0x44		/* D */
#define	ERASE_EOF	0x45		/* E */
#define INSRT		0x49		/* I */
#define RESET      	0x52		/* R */
#define INPUT_ERASE	0x58		/* X */

/* RSLT_EMC entries */

#define EM_ALTMACRO		'A'		/* set the ALT (mousedown state) modifier bit */
#define EM_NORMMACRO	'a'		/* always set ALT off */
#define EM_CLOSE		'C'		/* Close the emulator session */
#define EM_EDIT			'E'		/* show the textwindow */
#define EM_FILLCLOSE	'F'		/* close the copyright/help textwindow */
#define EM_HIDE			'H'		/* don't update the display */
#define EM_LITERAL		'L'		/* display literals in ASCII emulators */
#define EM_RESTORE		'R'		/* restore line 25 */
#define EM_SHOW			'S'		/* update the display as usual */
#define EM_TERM			'T'		/* show the "terminal" emwindow */
#define EM_TRACK		't'		/* toggle cursor tracking */
#define EM_TRYDSDRAW	'Z'		/* toggle fast drawing */

/* RSLT_LOOP entries */

/* DO WHILE loop begin: the entry for this class is the
   number of times to repeat the loop; a 0 will cause the loop to be skipped,
   a 255 will cause the loop to continue until interrupted by a "Command-.".
*/

/* RSLT_DELAY entries */

/* the entry is the time in seconds you wish to delay processing tokens */

/* RSLT_EDIT entries */

#define ED_SELALL		'A'
#define ED_APPEND		'B'
#define ED_COPY			'C'
#define ED_SELRESET		'R'
#define ED_STDMODE		'S'
#define ED_TABLEMODE	'T'
#define ED_PASTE		'V'
#define ED_WORDSELECT	'W'
#define ED_CUT			'X'

/* RSLT_FILE entries */

#define RF_APPEND		'A'
#define RF_APPENDTO		'B'
#define RF_PRINTDRAFT	'D'
#define RF_NAME			'N'
#define RF_PRINTSCREEN	'P'
#define RF_PRINTTEXT	'p'
#define RF_PRINTSCRAP	'Q'
#define RF_SAVE			'S'
#define RF_SAVEAS		'T'

/* entries for the RSLT_MVCR type (IBM cursor motion) */

#define HOME		0x30	/* 0 */
#define BACK_TAB	0x3c	/* < */
#define TAB_FWD		0x3e	/* > */
#define DOWN_ARROW	0x44	/* D */
#define LEFT_ARROW	0x4c	/* < */
#define NEW_LINE	0x4e	/* N */
#define RIGHT_ARROW 0x52	/* R */
#define UP_ARROW	0x55	/* U */

/* entries for the RSLT_PFKY class (IBM Program Function keys) */

#define  PF1		0x1
#define  PF2		0x2
#define  PF3		0x3
#define  PF4		0x4
#define  PF5		0x5
#define  PF6		0x6
#define  PF7		0x7
#define  PF8		0x8
#define  PF9		0x9
#define  PF10		0xa
#define  PF11		0xb
#define  PF12		0xc
#define  PF13		0xd
#define  PF14		0xe
#define  PF15		0xf
#define  PF16		0x10
#define  PF17		0x11
#define  PF18		0x12
#define  PF19		0x13
#define  PF20		0x14
#define  PF21		0x15
#define  PF22		0x16
#define  PF23		0x17
#define  PF24		0x18
#define  PF25		0x19
#define  PF26		0x1a
#define  PF27		0x1b
#define  PF28		0x1c
#define  PF29		0x1d
#define  PF30		0x1e
#define  PF31		0x1f
#define  PF32		0x20
#define  PF33		0x21
#define  PF34		0x22
#define  PF35		0x23
#define  PF36		0x24
#define  PA1		0x31
#define  PA2		0x32
#define  PA3		0x33
#define	 CLEAR		0x43
#define  ENTER		0x45
#define  PFSHIFT	0x55
#define  PFDUBSHIFT	0x57


/* the entry for the RSLT_YCURS type is the desired row numbered from 0 */
/* the entry for the RSLT_XCURS type is the desired column numbered from 0 */

/* the entry for the RSLT_SEL actions is the desired location numbered from 0 */

/* RSLT_TELNET entries */

